*******
Credits
*******

United is developed at the `Measurement Engineering Group`_ (EMT)
at `Paderborn University`_, Germany.

.. _Measurement Engineering Group: https://emt.uni-paderborn.de/
.. _Paderborn University: https://www.uni-paderborn.de/


Development Lead
================

* Kevin Koch <kevink2@mail.uni-paderborn.de>


Contributors
============

None yet. Why not be the first?
